@@ -1,6 +1,9 @@
 	project "vhacd"
 
 	kind "StaticLib"
+    if os.is("Linux") then
+        buildoptions{"-fPIC"}
+    end
 	includedirs {
 		"../inc","../public",
 	}
