@@ -5,7 +5,10 @@
 	kind "StaticLib"
 		
 	includedirs {".."}
-	targetdir "../../bin"
+
+    if os.is("Linux") then
+        buildoptions{"-fPIC"}
+    end
 
 	files {
 		"**.cpp",
