@@ -6,6 +6,9 @@
 		
 	includedirs {".."}
 	
+    if os.is("Linux") then
+        buildoptions{"-fPIC"}
+    end
 
 	files {
 		"**.cpp",
