@@ -14,7 +14,8 @@ typedef float idScalar;
 // template <typename T>
 // using idArray = std::vector<T>;
 template <typename T>
-struct idArray {
+struct idArray
+{
 	typedef std::vector<T> type;
 };
 typedef std::vector<int>::size_type idArrayIdx;
@@ -23,14 +24,14 @@ typedef std::vector<int>::size_type idArrayIdx;
 #define idMalloc ::malloc
 #define idFree ::free
 // currently not aligned at all...
-#define ID_DECLARE_ALIGNED_ALLOCATOR()															 \
-	inline void* operator new(std::size_t sizeInBytes) { return idMalloc(sizeInBytes); }		   \
-	inline void operator delete(void* ptr) { idFree(ptr); }										\
-	inline void* operator new(std::size_t, void* ptr) { return ptr; }							  \
-	inline void operator delete(void*, void*) {}												   \
-	inline void* operator new[](std::size_t sizeInBytes) { return idMalloc(sizeInBytes); }		 \
-	inline void operator delete[](void* ptr) { idFree(ptr); }									  \
-	inline void* operator new[](std::size_t, void* ptr) { return ptr; }							\
+#define ID_DECLARE_ALIGNED_ALLOCATOR()                                                     \
+	inline void* operator new(std::size_t sizeInBytes) { return idMalloc(sizeInBytes); }   \
+	inline void operator delete(void* ptr) { idFree(ptr); }                                \
+	inline void* operator new(std::size_t, void* ptr) { return ptr; }                      \
+	inline void operator delete(void*, void*) {}                                           \
+	inline void* operator new[](std::size_t sizeInBytes) { return idMalloc(sizeInBytes); } \
+	inline void operator delete[](void* ptr) { idFree(ptr); }                              \
+	inline void* operator new[](std::size_t, void* ptr) { return ptr; }                    \
 	inline void operator delete[](void*, void*) {}
 
 #include "details/IDMatVec.hpp"
