@@ -5,6 +5,9 @@
 	includedirs {
 		"..",
 	}
+    if os.is("Linux") then
+        buildoptions{"-fPIC"}
+    end
 	files {
 		"**.cpp",
 		"**.h"
