@@ -9,14 +9,14 @@
 #define BulletTest_Test_qtdot_h
 
 #ifdef __cplusplus
-extern "C" { 
+extern "C"
+{
 #endif
 
-int Test_qtdot(void);
+	int Test_qtdot(void);
 
 #ifdef __cplusplus
 }
 #endif
 
-    
 #endif
